@@ -300,6 +300,24 @@ class PyWebWizardBase:
             logging.error(f"[CONFIG] Error loading config: {str(e)}")
             raise ConfigFormatError(f"Error loading config: {str(e)}")
 
+    def _execute_action(self, action: dict):
+        """
+        Executes a single action.
+
+        :param action: Action dictionary.
+        """
+        action = self.prepare_action(action)
+        _action_name = action.get('action')
+        if _action_name not in self.actions_map:
+            raise ActionError(f"'{_action_name}' action not supported")
+        try:
+            return self.actions_map.get(_action_name)(action)
+        except Exception:
+            if action.get('optional', False):
+                logging.info(f"[{_action_name.upper()}] Optional action could not be runned... Ignoring")
+            else:
+                raise
+
     def _replace_env(self, search_value):
         pattern = r"\{\{\s*(\w+)\s*\}\}"
 
