@@ -24,19 +24,26 @@ class AIController:
         self.tools = [
             {
                 "type": "function",
-                "name": "do_action",
-                "description": "Performs an action on a website.",
-                "parameters": {
-                    "type": "object",
-                    "properties": {
-                        "action": {"type": "object"}
-                    },
-                    "required": ["action"],
-                    "additionalProperties": False
-                },
-                "strict": True
+                "function": {
+                    "name": "do_action",
+                    "description": "Performs one or more actions on a website.",
+                    "parameters": {
+                        "type": "object",
+                        "properties": {
+                            "action": {
+                                "type": "array",
+                                "items": {
+                                    "type": "object"
+                                }
+                            }
+                        },
+                        "required": ["action"],
+                        "additionalProperties": False
+                    }
+                }
             }
         ]
+
         
     def analyze_task(self, task_description: str, current_page_info: Dict[str, Any]) -> List[Dict[str, Any]]:
         """
@@ -208,7 +215,7 @@ class AIController:
             Generate a list of actions in JSON format.
             """
             
-            response = self.client.responses.create(
+            response = self.client.chat.completions.create(
                 model=self.model,
                 messages=[
                     {"role": "system", "content": system_prompt},
@@ -219,13 +226,15 @@ class AIController:
                 tools=self.tools,
                 tool_choice="required"
             )
-            
-            tool_call = response.output[0]
-            _action = json.loads(tool_call.action)
-            
+
+            tool_call = response.choices[0].message.tool_calls[0]
+            tool_call = json.loads(tool_call.to_json())
+            _action = tool_call.get("arguments", "{}")
+            _action = json.loads(_action)
+
             if not isinstance(_action, list):
                 _action = [_action]
-            
+
             return _action
             
         except json.JSONDecodeError as e:
